@@ -14,12 +14,12 @@ from string import Template
 
 import click
 import discord
+import dunamai as _dunamai
 import matplotlib
 import matplotlib.dates as mdates
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import poetry_version
 import pytz
 from yaml import load
 
@@ -28,7 +28,9 @@ try:
 except ImportError:  # pragma: no cover
     from yaml import Loader
 
-__version__ = poetry_version.extract(source_file=__file__)
+__version__ = _dunamai.get_version(
+    "turbot", third_choice=_dunamai.Version.from_any_vcs
+).serialize()
 
 matplotlib.use("Agg")
 
@@ -1517,6 +1519,7 @@ def get_channels(channels_file):  # pragma: no cover
     default=DEFAULT_DB_USERS,
     help="read users preferences data from this file",
 )
+@click.version_option(version=__version__)
 def main(
     log_level,
     verbose,
